@@ -1,9 +1,8 @@
+from django.conf import settings
 from django.db import models
 from django.utils.encoding import smart_str
 from geopy import geocoders
 
-
-
 class Address(models.Model):
     address = models.CharField(max_length=255, db_index=True)
     computed_address = models.CharField(max_length=255, null=True, blank=True)
@@ -16,11 +15,14 @@ class Address(models.Model):
             self.geocode_error = True
             return
         try:
-            g = geocoders.Google(resource='maps')
+            if hasattr(settings, "EASY_MAPS_GOOGLE_KEY") and settings.EASY_MAPS_GOOGLE_KEY:
+                g = geocoders.Google(settings.EASY_MAPS_GOOGLE_KEY)
+            else:
+                g = geocoders.Google(resource='maps')
             address = smart_str(self.address)
             self.computed_address, (self.latitude, self.longitude,) = g.geocode(address)
             self.geocode_error = False
-        except (UnboundLocalError, ValueError,):
+        except (UnboundLocalError, ValueError,geocoders.google.GQueryError):
             self.geocode_error = True
 
     def save(self, *args, **kwargs):
